@@ -88,7 +88,7 @@ patterns <- function(x) {
   colnames(databpr) <- colnames(x)
   return(list(w = wfn, databp_red = databpr, names = colnames(x)))
 }
-estimaterates <- function(usertree = NULL, userphyl = NULL, matchtipstodata = FALSE, unobserved = NULL, alphabet = NULL, modelmat = NULL, bgtype = "listofnodes", bg = NULL, partition = NULL, ratevar = FALSE, nocat = 4, reversible = FALSE, numhessian = TRUE,  rootprob = NULL, rpvec = NULL, lowli = 0.001, upli = 100, ...) {
+estimaterates <- function(usertree = NULL, userphyl = NULL, matchtipstodata = FALSE, unobserved = NULL, alphabet = NULL, modelmat = NULL, bgtype = "listofnodes", bg = NULL, partition = NULL, ratevar = FALSE, nocat = 4, reversible = FALSE, numhessian = TRUE,  rootprob = NULL, rpvec = NULL, init = 0.9, lowli = 0.001, upli = 100, ...) {
   ptm <- proc.time()
   if (ratevar != FALSE) ratevar <- match.arg(ratevar,c("discgamma","partitionspecificgamma"))
   bgtype <- match.arg(bgtype, c("listofnodes", "ancestornodes"))
@@ -98,8 +98,11 @@ estimaterates <- function(usertree = NULL, userphyl = NULL, matchtipstodata = FA
     stop("usertree option is required.")
   if (is.null(userphyl) | !(is.matrix(userphyl) | is.data.frame(userphyl))) 
     stop("userphyl option is required.")
-  if (!is.null(unobserved) & !is.matrix(userphyl)) 
-    stop("unobserved should be a matrix.")
+  if (!is.null(unobserved)) {
+    if (!(is.matrix(unobserved) | is.data.frame(unobserved))) { 
+    stop("unobserved option should be a matrix.")
+    }
+  }
   if (bgtype == "listofnodes" & !is.null(bg) & !is.list(bg))
     stop("bg should be a vector with listofnodes argument.")
   if (bgtype == "listofnodes" & !is.null(bg) & is.list(bg)) {
@@ -236,13 +239,14 @@ estimaterates <- function(usertree = NULL, userphyl = NULL, matchtipstodata = FA
   ###########Data Import#########
   if (!ape::is.binary.tree(usertree) | !ape::is.rooted(usertree)) {
     usertree <- ape::multi2di(usertree)
-    cat("Tree either not binary or not rooted.", "\n", "Transformed using multi2di from packege ape.", "\n")
+    cat("Tree either not binary or not rooted.", "\n", "Transformed using multi2di from package ape.", "\n")
     cat("Labels of nodes of interest might change.\n")
   }
   tree1 <- usertree
   tree1 <- ape::reorder.phylo(tree1, order = "postorder")
   
   if (is.data.frame(userphyl)) userphyl <- as.matrix(userphyl)
+  if (is.data.frame(unobserved)) unobserved <- as.matrix(unobserved)
   diag(modelmat) <- NA
   if (reversible & !isSymmetric(modelmat)) stop("modelmat should be symmetric to use with the reversible option.")
   if (reversible & rootprob != "maxlik") stop("Root probabilities must be estimated using likelihood to use with the reversible option. Use maxlik option for rootprob.")
@@ -560,7 +564,7 @@ estimaterates <- function(usertree = NULL, userphyl = NULL, matchtipstodata = FA
       return(rep(list(rpvec), psp))
     }
   }
-  indelinit <- 0.9
+  indelinit <- init
   ################Estimation################
   alphastart = 0.5
   options(digits = 7)
